package data_manage

import (
	"github.com/beego/beego/v2/client/orm"
	"time"
)

type EdbClassify struct {
	ClassifyID         int64     `orm:"column(classify_id);pk"`
	ClassifyType       uint32    `orm:"column:classify_type;default:0;comment:'分类类型，0：普通指标分类，1：预测指标分类'"`
	ClassifyName       string    `orm:"column:classify_name;not null;default:'';comment:'分类名称'"`
	ParentID           int64     `orm:"column:parent_id;not null;default:0;comment:'父级id'"`
	HasData            int32     `orm:"column:has_data;default:0;comment:'是否存在指标数据:1有，2：无'"`
	CreateTime         time.Time `orm:"column:create_time"`
	ModifyTime         time.Time `orm:"column:modify_time"`
	SysUserID          int64     `orm:"column:sys_user_id;comment:'创建人id'"`
	SysUserRealName    string    `orm:"column:sys_user_real_name;size:50;comment:'创建人姓名'"`
	Level              int64     `orm:"column:level;default:0;comment:'层级'"`
	UniqueCode         string    `orm:"column:unique_code;size:50"`
	Sort               uint32    `orm:"column:sort;unsigned;default:10;comment:'排序字段，越小越靠前，默认值：10'"`
	RootID             int64     `orm:"column:root_id;not null;default:0;comment:'顶级ID'"`
	LastModifyUserID   uint32    `orm:"column:last_modify_user_id;unsigned;not null;default:0;comment:'最后修改人ID'"`
	LastModifyUserName string    `orm:"column:last_modify_user_real_name;size:64;not null;default:'';comment:'最后修改人姓名'"`
}

// GetAllEdbClassifyListByCondition
// @Description: 获取分类列表
// @author: Roc
// @datetime 2024-02-29 10:55:38
// @param condition string
// @param pars []interface{}
// @return item []*EdbInfoUpdateLog
// @return err error
func GetAllEdbClassifyListByCondition(condition string, pars []interface{}) (item []*EdbClassify, err error) {
	o := orm.NewOrmUsingDB("data")
	sql := ` SELECT * FROM edb_classify WHERE 1=1 `
	if condition != "" {
		sql += condition
	}
	sql += `ORDER BY classify_id ASC `
	_, err = o.Raw(sql, pars).QueryRows(&item)

	return
}
